@@ -1,7 +1,11 @@
 package Sah::Schemas::Path;
 
-our $DATE = '2021-07-17'; # DATE
-our $VERSION = '0.016'; # VERSION
+use strict;
+
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2023-08-11'; # DATE
+our $DIST = 'Sah-Schemas-Path'; # DIST
+our $VERSION = '0.017'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -18,10 +22,12 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.016 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2021-07-17.
+This document describes version 0.017 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-08-11.
 
 =head1 SAH SCHEMAS
 
+The following schemas are included in this distribution:
+
 =over
 
 =item * L<dirname|Sah::Schema::dirname>
@@ -43,6 +49,18 @@ What's the difference between this schema and C<filename>? The default completio
 rule. This schema's completion by default only includes directories.
 
 
+=item * L<dirname::exists|Sah::Schema::dirname::exists>
+
+Directory name, must exist on filesystem.
+
+=item * L<dirname::unix|Sah::Schema::dirname::unix>
+
+Filesystem directory name on a Unix system.
+
+=item * L<dirnames::exist|Sah::Schema::dirnames::exist>
+
+List of directory names, all must exist on filesystem.
+
 =item * L<filename|Sah::Schema::filename>
 
 Filesystem file name.
@@ -63,6 +81,25 @@ rule. This schema's completion by default only includes files and not
 directories.
 
 
+=item * L<filename::exists|Sah::Schema::filename::exists>
+
+File name, must exist on filesystem.
+
+=item * L<filename::unix|Sah::Schema::filename::unix>
+
+Filesystem file name on a Unix system.
+
+=item * L<filenames|Sah::Schema::filenames>
+
+List of filesystem file names.
+
+Coerces from string by expanding the glob pattern in the string.
+
+
+=item * L<filenames::exist|Sah::Schema::filenames::exist>
+
+List of file names, all must exist on filesystem.
+
 =item * L<pathname|Sah::Schema::pathname>
 
 Filesystem path name.
@@ -83,6 +120,14 @@ default completion rule. This schema's completion by default includes
 files as well as directories.
 
 
+=item * L<pathname::exists|Sah::Schema::pathname::exists>
+
+Path name, must exist on filesystem.
+
+=item * L<pathname::unix|Sah::Schema::pathname::unix>
+
+Filesystem path name on a Unix system.
+
 =item * L<pathnames|Sah::Schema::pathnames>
 
 List of filesystem path names.
@@ -90,6 +135,10 @@ List of filesystem path names.
 Coerces from string by expanding the glob pattern in the string.
 
 
+=item * L<pathnames::exist|Sah::Schema::pathnames::exist>
+
+List of path names, all must exist on filesystem.
+
 =back
 
 =head1 HOMEPAGE
@@ -100,6 +149,47 @@ Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schema
 
 Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Path>.
 
+=head1 SEE ALSO
+
+L<Sah> - schema specification
+
+L<Data::Sah> - Perl implementation of Sah
+
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTOR
+
+=for stopwords Gabor Szabo
+
+Gabor Szabo <gabor@szabgab.com>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2023, 2020, 2019, 2018, 2016 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Path>
@@ -108,21 +198,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 SEE ALSO
-
-L<Sah> - specification
-
-L<Data::Sah>
-
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2021, 2020, 2019, 2018, 2016 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
